#
# spec file for package kosmindoormap
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.6.0
%define qt6_version 6.6.0

%bcond_without released
Name:           kosmindoormap
Version:        25.04.2
Release:        1.1
Summary:        OSM multi-floor indoor map renderer
License:        LGPL-2.0-or-later AND CC0-1.0
URL:            https://apps.kde.org/kosmindoormap
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  bison
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  flex
BuildRequires:  pkgconfig
BuildRequires:  qt6-base-private-devel >= %{qt6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KOpeningHours)
BuildRequires:  cmake(KPublicTransport)
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  cmake(Qt6Test) >= %{qt6_version}
# Fails because of https://bugzilla.opensuse.org/show_bug.cgi?id=1222343
%if 0%{?suse_version} > 1500 || 0%{?sle_version} > 150500
BuildRequires:  pkgconfig(protobuf)
%endif
BuildRequires:  pkgconfig(zlib)

%description
OSM multi-floor indoor map renderer.

%package imports
Summary:      QML imports for kosmindoormap
Requires:     libKOSM1 = %{version}
Requires:     libKOSMIndoorRouting1 = %{version}

%description imports
QML components for KOpeningHours.

%package -n libKOSM1
Summary:        OSM primitives for kosmindoormap
Requires:       kosmindoormap >= %{version}

%description -n libKOSM1
OSM primitives for kosmindoormap.

%package -n libKOSMIndoorMap1
Summary:        OSM multi-floor indoor map renderer

%description -n libKOSMIndoorMap1
OSM multi-floor indoor map renderer library.

%package -n libKOSMIndoorRouting1
Summary:        OSM multi-floor indoor map renderer

%description -n libKOSMIndoorRouting1
Indoor routing component of kosmindoormap, an OSM 
multi-floor indoor map renderer

%package devel
Summary:        Development package for kosmindoormap
Requires:       libKOSM1 = %{version}
Requires:       libKOSMIndoorMap1 = %{version}
Requires:       libKOSMIndoorRouting1 = %{version}

%description devel
Development files for the KOSM and KOSMIndoorMap libraries.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf6 -DBUILD_TESTING=ON

%kf6_build

%install
%kf6_install

%find_lang %{name}

%check
# Two tests fail on i586 (one minor floating point issue and a color one).
# Upstream is investigating
%ifnarch i586
%ctest
%endif

%ldconfig_scriptlets -n libKOSM1
%ldconfig_scriptlets -n libKOSMIndoorMap1
%ldconfig_scriptlets -n libKOSMIndoorRouting1

%files
%{_kf6_debugdir}/org_kde_kosmindoormap.categories

%files imports
%{_kf6_qmldir}/org/kde/kosmindoormap/
%{_kf6_qmldir}/org/kde/kosmindoorrouting/
%{_kf6_qmldir}/org/kde/osm/

%files -n libKOSM1
%license LICENSES/*
%doc README.md
%{_kf6_libdir}/libKOSM.so.*

%files -n libKOSMIndoorMap1
%{_kf6_libdir}/libKOSMIndoorMap.so.*

%files -n libKOSMIndoorRouting1
%{_kf6_libdir}/libKOSMIndoorRouting.so.*

%files devel
%{_includedir}/KOSM/
%{_includedir}/KOSMIndoorMap/
%{_includedir}/KOSMIndoorRouting/
%{_includedir}/kosm/
%{_includedir}/kosmindoormap/
%{_includedir}/kosmindoorrouting/
%{_includedir}/kosmindoormap_version.h
%{_kf6_cmakedir}/KOSMIndoorMap/
%{_kf6_libdir}/libKOSM.so
%{_kf6_libdir}/libKOSMIndoorMap.so
%{_kf6_libdir}/libKOSMIndoorRouting.so

%files lang -f %{name}.lang

%changelog
* Tue Jun  3 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.2/
- Changes since 25.04.1:
  * Update Kirigami Addons
* Wed May  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.1/
- Changes since 25.04.0:
  * Update Kirigami Addons
  * Fix build with Qt 6.10
* Mon Apr 14 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.0/
- No code change since 25.03.90
* Sat Mar 29 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.03.90
  * New feature release
- Changes since 24.12.3:
  * Fix Wikidata cache path
  * Remove unused string from Android manifest
  * Use KPublicTransport.TransportIcon to show line logos
  * Rename f-droid icon to begin according to name in AndroidManifest
  * Add icon for f-droid file listing
  * Don't hide tunneled waterways unconditionally
  * Don't draw unintended outlines around waterway areas
  * Add infrastructure for determining close way types
  * Initial support for textured line fills
  * Implement limiting labels to a bounding polygon
  * Update static build versions for 24.12
* Tue Mar  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.3/
- No code change since 24.12.2
* Tue Feb  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.2/
- Changes since 24.12.1:
  * Remove unused string from Android manifest
* Tue Jan  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.1/
- Changes since 24.12.0:
  * Don't draw unintended outlines around waterway areas
  * Add infrastructure for determining close way types
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.0/
- No code change since 24.11.90
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.90
  * New feature release
- Changes since 24.11.80:
  * Build Flatpak from release branches
* Sat Nov 16 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.80
  * New feature release
- Too many changes to list here.
* Tue Nov  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.3/
- Changes since 24.08.2:
  * Add missing org.kde.contacts dependency
  * Remove too aggressive operator< overload
  * Add namespace for Android as required by newer gradle versions
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.2/
- Changes since 24.08.1:
  * The routing QML API does not depend on KPublicTransport
* Tue Sep 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.1/
- No code change since 24.08.0
* Mon Aug 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.0/
- Too many changes to list here.
* Tue Jul  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.2/
- Changes since 24.05.1:
  * Check for errors when mmap'ing tile files
* Wed Jun 12 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.1/
- No code change since 24.05.0
* Sun May 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.0/
- Changes since 24.04.80:
  * Fix memory leak in parsing MapCSS conditions
  * Build against dependencies from the stable branch
* Fri May  3 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.04.80
  * New feature release
- Too many changes to list here.
* Tue Apr  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.2/
- Changes since 24.02.1:
  * Fix about dialog missing data and showing an outdated version number
  * Don't force master for Craft dependencies anymore
* Tue Mar 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.1/
- Changes since 24.02.0:
  * Move Craft ignore file here
  * Use the KF6 Flatpak runtime
* Tue Mar 12 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Move the %%find_lang call into %%install section
* Fri Feb 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.0
  * New feature release
- Changes since 24.01.95:
  * Fix possible crash during teardown/shutdown
* Fri Feb  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.01.95
  * https://kde.org/announcements/megarelease/6/rc2/
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- No code change since 23.08.3
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- No code change since 23.08.2
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- Changes since 23.08.1:
  * Render waterfalls, public book cases and co-working spaces
  * Match not found tag keys against the KeyNotSet operator
  * Improve rendering of some tourist attractions
  * Handle another Wikepedia link tagging variant
  * Render showers as well
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- Changes since 23.08.0:
  * Handle another luggage locker tagging variant
  * Show the type of diplomatic entities in the info box
  * Add consulate icon, show labels for embassys
  * Render food courts, clinics and an alternative travel agency tagging
  * Handle network:wikipedia tags in the same way we handle operator:wikipedia
  * Display lost & found offices
  * Display airport baggage claim belts
  * Add luggage locker icon
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- Changes since 23.07.90:
  * Add luggage locker icon
  * Fix rendering of closed non-area walls
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- No code change since 23.07.80
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Changes since 23.04.3:
  * Use protobuf's cmake config if available
  * Use protobuf cmake targets instead of variables
  * Show transliterated names when available and useful
  * .gitignore ignore compile_commands.json
  * Explicitly set target interface include directories
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- No code change since 23.04.2
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- No code change since 23.04.1
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- Changes since 23.04.0:
  * Consider local names as alternative when no element name is available
  * Enable info boxes for trees
  * Fix hit detection for icons using a physical size
  * Implement MapCSS text-position declarations properly
  * Render kerb lines much less prominently
  * Support setting negative numeric tag values in MapCSS
  * Better distinguish rendering of different barrier types
  * Render shrubs
  * Fix display of service roads in light style
  * Add User-Agent header for downloading map tiles
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Fri Mar 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Wed Mar 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Changes since 21.12.3:
  * Fill in missing country/state information based on the coordinate
  * Port deprecated QStandardPaths::DataLocation
  * Add basic translation for boolean-like tag values
  * Port rental vehicle details to KLazyLocalizedString as well
  * Port static message tables from I18N_NOOP to KLazyLocalizedString
  * Translate title
  * Setup Gitlab CI
  * Try to activate new CI
* Tue Mar  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- Changes since 21.12.2:
  * Format user visible numbers using the current locale
* Tue Feb  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- No code change since 21.12.1
* Tue Jan  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- No code change since 21.12.0
* Fri Dec  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.0/
- No code change since 21.11.90
* Sat Nov 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.90
  * New feature release
- No code change since 21.11.80
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.80
  * New feature release
- Changes since 21.08.3:
  * Allow the platform model to match platforms on all their properties
  * Add properties to Platform for direct access from QML
  * Remove the Platform::lines public member
  * Add dptr to Platform as well
  * Prepare PlatformSection to become proper public API
  * Don't attempt platform section merging when there is only one
  * Fix pinch zoom conflicting with map panning
  * Consider IFOPT platform ids for merging platform elements
  * Ignore disused platform elements
  * Add styling for tourism=gallery
  * Show details about available rental vehicles
  * Also expose the available vehicles by type for rental docks
  * Implement pole of inaccessibility algorithm
  * Separate dock-based and floating rental vehicles
  * Port to the new logging category macros
  * Port from QStringRef to QStringView
  * Display remaining range of rental vehicles when available
  * Add corresponding icons for all free-floating rental vehicle types
  * Give free-floating rental kick scooters their own icon
  * Add CMakePresets support
  * It compiles without deprecated method
  * Upgrade to KDECompilerSettings 5.85
  * replace "MacOSX" with "macOS"
* Tue Nov  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.3/
- No code change since 21.08.2
* Tue Oct  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.2/
- Changes since 21.08.1:
  * Properly handle intermediate floor levels in equipment model
  * Handle another way of tagging emankments
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.1
- Changes since 21.08.0:
  * Work around CMake Protobuf support not dealing with missing protoc
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.0
- No code change since 21.07.90
* Fri Jul 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.90
  * New feature release
- No code change since 21.07.80
* Sat Jul 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.80
  * New feature release
- Changes since 21.04.3:
  * Migrate to new REUSE CI check
  * Also show tracks and paths
  * Use the newly supported layer selectors to untangle roads and tramways
  * Add layer selector support to the scene graph
  * Implement layer selector support in MapCSS union selectors
  * Prepare MapCSS selector matching to support layer selectors
  * Prepare MapCSSResult for carrying results for multiple layer selectors
  * Handle default layer selector
  * Use unique string keys for class and layer selectors
  * Factor out the  unique string key pool from OSM::DataSet
  * Expand MapCSS grammar for supporting layer selectors
  * Handle another way of tagging inaccessible elevators
  * Add i18n context for "socket"
  * Add information icons from OSM carto
  * Increase the minimum Qt version to 5.15 here too
* Wed Jul  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.3
- Changes since 21.04.2:
  * Remove the boundary filter
* Tue Jun  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.2
- No code change since 21.04.1
* Wed May 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/21.04.1
- No code change since 21.04.0
* Fri Apr 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04
- Changes since 21.03.90:
  * Actually build without QtWidgets
* Fri Apr  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.90
  * New feature release
- No code change since 21.03.80
* Sun Mar 21 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.80
  * New feature release
- Too many changes to list here.
* Thu Mar  4 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/20.12.3
- No code change since 20.12.2
* Wed Feb  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-02-apps-update
- No code change since 20.12.1
* Tue Jan  5 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-01-apps-update
- No code change since 20.12.0
* Sat Dec  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-12-apps-update
- No code change since 20.11.90
* Fri Nov 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.90
  * New feature release
- Changes since 20.11.80:
  * Massively reduce the node matching distance for geometry reassembly
  * Fix build with Qt 5.14
  * Enable HTTP2 support when available
  * Set SOVERSION to a fixed value
  * Fix 32bit color parsing on 32bit architectures
* Sat Nov 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Initial package
